%global _docdir_fmt %{name}

Name: bullet
Version: 3.08
Release:    2%{?dist}
Summary: 3D Collision Detection and Rigid Body Dynamics Library
License: zlib and MIT and BSD and Boost
URL: http://www.bulletphysics.com

Source0: %{name}3-%{version}-free.tar.xz
Source1: generate-tarball.sh

Patch0: %{name}-3.08-tinyxml2.patch

Patch1: %{name}-3.08-fix-c++-one-definition-rule-violation.patch

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires: cmake
BuildRequires: dos2unix
BuildRequires: doxygen
BuildRequires: freeglut-devel
BuildRequires: libICE-devel
BuildRequires: tinyxml2-devel
BuildRequires: libglvnd-devel

%description
Bullet is a 3D Collision Detection and Rigid Body Dynamics Library for games
and animation.


%package devel
Summary: Development files for %{name}
Requires: %{name} = %{version}-%{release}
Requires: cmake
%description devel
Development headers and libraries for %{name}.


%package devel-doc
Summary: Documentation for developing programs that will use %{name}-devel
License: zlib and LGPLv2+
Requires: %{name}-extras = %{version}-%{release}

%description devel-doc
Documentation (PDF) for developing programs that will use %{name}-devel.


%package extras
Summary: Extra libraries for %{name}
License: zlib and LGPLv2+

%description extras
Extra libraries for %{name}.


%package extras-devel
Summary: Development files for %{name} extras
License: zlib and LGPLv2+
Requires: %{name}-extras = %{version}-%{release}
Requires: %{name}-devel = %{version}-%{release}

%description extras-devel
Development headers and libraries for %{name} extra libraries.


%prep
%setup -q -n %{name}3-%{version}
%patch0 -p1 -b .tinyxml
%patch1 -p1 -b .fix-odr
rm -r examples

sed -i 's|${prefix}/@INCLUDE_INSTALL_DIR@|@INCLUDE_INSTALL_DIR@|' bullet.pc.cmake

sed -i 's|BulletRoboticsGUI BulletRobotics||' Extras/CMakeLists.txt
sed -i 's|obj2sdf||' Extras/CMakeLists.txt

dos2unix README.md
chmod -x src/BulletDynamics/ConstraintSolver/btSliderConstraint.h
chmod -x src/BulletDynamics/ConstraintSolver/btSliderConstraint.cpp

%build
%cmake \
  -DCLSOCKET_DEP_ONLY=ON \
  -DBUILD_BULLET2_DEMOS=OFF \
  -DBUILD_EXTRAS=ON \
  -DBUILD_OPENGL_DEMOS=OFF \
  -DBUILD_CPU_DEMOS=OFF \
  -DBUILD_UNIT_TESTS=OFF \
  -DINSTALL_EXTRA_LIBS=ON \
  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
  -DOpenGL_GL_PREFERENCE=GLVND \
  -DINCLUDE_INSTALL_DIR=%{_includedir}/bullet/

%cmake_build

doxygen Doxyfile

%install
%cmake_install





%files
%license LICENSE.txt
%doc README.md AUTHORS.txt VERSION
%{_libdir}/libBullet3Collision.so.*
%{_libdir}/libBullet3Common.so.*
%{_libdir}/libBullet3Dynamics.so.*
%{_libdir}/libBullet3Geometry.so.*
%{_libdir}/libBullet3OpenCL_clew.so.*
%{_libdir}/libBulletCollision.so.*
%{_libdir}/libBulletDynamics.so.*
%{_libdir}/libBulletInverseDynamics.so.*
%{_libdir}/libBulletSoftBody.so.*
%{_libdir}/libLinearMath.so.*

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_includedir}/%{name}/Bullet3Collision
%{_includedir}/%{name}/Bullet3Common
%{_includedir}/%{name}/Bullet3Dynamics
%{_includedir}/%{name}/Bullet3Geometry
%{_includedir}/%{name}/Bullet3OpenCL
%{_includedir}/%{name}/BulletCollision
%{_includedir}/%{name}/BulletDynamics
%{_includedir}/%{name}/BulletInverseDynamics
%{_includedir}/%{name}/BulletSoftBody
%{_includedir}/%{name}/InverseDynamics
%{_includedir}/%{name}/LinearMath
%{_libdir}/libBullet3Collision.so
%{_libdir}/libBullet3Common.so
%{_libdir}/libBullet3Dynamics.so
%{_libdir}/libBullet3Geometry.so
%{_libdir}/libBullet3OpenCL_clew.so
%{_libdir}/libBulletCollision.so
%{_libdir}/libBulletDynamics.so
%{_libdir}/libBulletInverseDynamics.so
%{_libdir}/libBulletSoftBody.so
%{_libdir}/libLinearMath.so
%{_libdir}/pkgconfig/bullet.pc
%{_libdir}/cmake/%{name}

%files devel-doc
%doc docs/Bullet_User_Manual.pdf
%doc docs/BulletQuickstart.pdf
%doc docs/GPU_rigidbody_using_OpenCL.pdf
%doc html

%files extras
%{_libdir}/libConvexDecomposition.so.*
%{_libdir}/libGIMPACTUtils.so.*
%{_libdir}/libHACD.so.*
%{_libdir}/libBulletFileLoader.so.*
%{_libdir}/libBullet2FileLoader.so.*
%{_libdir}/libBulletInverseDynamicsUtils.so.*
%{_libdir}/libBulletWorldImporter.so.*
%{_libdir}/libBulletXmlWorldImporter.so.*

%files extras-devel
%{_includedir}/%{name}/ConvexDecomposition
%{_includedir}/%{name}/GIMPACTUtils
%{_includedir}/%{name}/HACD
%{_includedir}/%{name}/BulletFileLoader
%{_includedir}/%{name}/Bullet2FileLoader
%{_includedir}/%{name}/BulletWorldImporter
%{_includedir}/%{name}/BulletXmlWorldImporter
%{_libdir}/libConvexDecomposition.so
%{_libdir}/libGIMPACTUtils.so
%{_libdir}/libHACD.so
%{_libdir}/libBulletFileLoader.so
%{_libdir}/libBullet2FileLoader.so
%{_libdir}/libBulletInverseDynamicsUtils.so
%{_libdir}/libBulletWorldImporter.so
%{_libdir}/libBulletXmlWorldImporter.so

%changelog
* Tue Jun 03 2025 bbrucezhang <bbrucezhang@tencent.com> - 3.08-2
- Rebuilt for loongarch64

* Thu Apr 11 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.08-1
- initial build
